@@ -113,64 +113,3 @@ test_that("rboxes derivatives error correctly", {
     )
   }
 })
-
-test_that("`myarray2vec()` works", {
-  skip_if_not_installed("arrayhelpers")
-  mat <- matrix(
-    c(
-      9, 13, 2, 6,
-      7, 5, 15, 12,
-      1, 10, 3, 8,
-      4, 11, 16, 14
-    ),
-    nrow = 4, byrow = TRUE
-  )
-  d <- rep(99, 4)
-  expect_equal(myarray2vec(mat, d), arrayhelpers::array2vec(mat, d))
-  expect_error(
-    myarray2vec(mat, rep(2, 2)),
-    paste0(
-      "Number of columns in `iarr` and number of dimensions\\s?",
-      "must be.+the same.+There are 4 columns in `iarr` and\\s?",
-      "you have specified 2.+dimensions."
-    )
-  )
-  set.seed(2)
-  expect_error(
-    myarray2vec(matrix(c(
-      1, 3, 1, 4,
-      4, 1, 1, 2,
-      3, 2, 4, 5,
-      1, 5, 5, 3
-    ),
-    nrow = 4, byrow = TRUE
-    ),
-    dim = rep(4, 4)
-    ),
-    paste0(
-      "You are requesting an array index outside the\\s?",
-      "dimension of.+your array.+Row 3 of `iarr` is `c\\(3, 2,\\s?",
-      "4, 5\\)` and `dim` is `c\\(4, 4,.+4, 4\\)`, so element 4\\s?",
-      "of that row, 5, is too big as it is.+bigger than\\s?",
-      "element 4 of `dim`, 4."
-    )
-  )
-  vec <- sample.int(max(d), length(d))
-  expect_equal(myarray2vec(vec, d), myarray2vec(matrix(vec, nrow = 1), d))
-  for (i in seq_len(999)) {
-    array_dims <- sample.int(99,
-      size = sample(2:99, size = 1),
-      replace = TRUE
-    )
-    n_elements <- sample.int(99, size = 1)
-    index_mat <- purrr::map(
-      array_dims,
-      ~ sample.int(.x, size = n_elements, replace = TRUE)
-    ) %>%
-      do.call(cbind, .)
-    expect_equal(
-      myarray2vec(index_mat, array_dims),
-      arrayhelpers::array2vec(index_mat, array_dims)
-    )
-  }
-})
